==> carbatpy-0.1.3.tar.gz: carbatpy-0.1.3/setup.py <==
#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [ ]

test_requirements = [ ]

setup(
    author="Burak Atakan",
    author_email='burak.atakan@uni-due.de',
    python_requires='>=3.6',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
    ],
    description="Modeling Carnot Batteries (Thermal Energy Storage), a Python package.",
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='carbatpy',
    name='carbatpy',
    packages=find_packages(include=['carbatpy', 'carbatpy.*']),
    test_suite='tests',
    tests_require=test_requirements,
    url='https://git.uni-due.de/spp-2403/td-ude/carbatpy',
    version='0.1.2',
    zip_safe=False,
)

==> carbatpy-0.1.5.tar.gz: carbatpy-0.1.5/setup.py <==
#!/usr/bin/env python

"""The setup script."""

from setuptools import setup, find_packages

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [ ]

test_requirements = [ ]

setup(
    author="Burak Atakan",
    author_email='burak.atakan@uni-due.de',
    python_requires='>=3.6',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
    ],
    description="Modeling Carnot Batteries (Thermal Energy Storage), a Python package.",
    install_requires=requirements,
    license="MIT license",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='carbatpy',
    name='carbatpy',
    packages=find_packages(include=['carbatpy', 'carbatpy.*', 'src', 'tests' ]),
    test_suite='tests',
    tests_require=test_requirements,
    url='https://git.uni-due.de/spp-2403/td-ude/carbatpy',
    version='0.1.5',
    zip_safe=False,
)
